==> libraries_delay_load-1.0.x-dev.tar.gz: libraries_delay_load/src/Form/ModuleConfigurationForm.php <==
<?php

namespace Drupal\libraries_delay_load\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures forms module settings.
 */
class ModuleConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'libraries_delay_load_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'libraries_delay_load.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('libraries_delay_load.settings');

    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Load Delay Library?'),
      '#default_value' => $config->get('enabled') ?? 0,
      '#description' => $this->t('Disable for testing purposes.'),
    ];

    $form['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable debug mode?'),
      '#default_value' => $config->get('debug') ?? 0,
      '#description' => $this->t('Display notices messages the first time a page is loaded to list all the javascripts loaded directly by Drupal. Also output the order of what is loaded in the console'),
    ];

    $form['jsExcluded'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Select javascript to exclude'),
      '#default_value' => $config->get('jsExcluded'),
      '#description' => $this->t('1 javascript path per line. eg: @example', ['@example' => 'core/assets/vendor/html5shiv/html5shiv.min.js']),
    ];

    $nbGroups = $config->get('nbGroups') ?? 2;
    $form['nbGroups'] = [
      '#type' => 'hidden',
      '#value' => $nbGroups,
    ];

    $jsGroups = $config->get('jsGroups');
    for ($i = 0; $i < $nbGroups; $i++) {
      $form['jsGroup' . $i] = [
        '#type' => 'fieldset',
        '#title' => $this->t('Group @number', ['@number' => $i]),
      ];

      if ($i == 0) {
        $title = $this->t('How long should this group start to be loaded after the window load event is fired (in ms)');
      }
      else {
        $title = $this->t('How long should this group start to be loaded after the load of the previous group is completed (in ms)');
        $description = $this->t('If the previous group is loaded asynchronously, scripts from this group could start to be downloaded before previous ones are executed / finished');
      }
      $form['jsGroup' . $i]['timing' . $i] = [
        '#type' => 'number',
        '#title' => $title,
        '#default_value' => $jsGroups[$i]['timing'] ?? 0,
        '#description' => $description ?? '',
      ];
      $form['jsGroup' . $i]['synchro' . $i] = [
        '#type' => 'radios',
        '#title' => $this->t('Scripts in that group to be loaded one after the other (synchro) or at any time (asynchro)'),
        '#default_value' => $jsGroups[$i]['synchro'] ?? 1,
        '#options' => [
          0 => $this->t('Asynchro'),
          1 => $this->t('Synchro'),
        ],
        '#description' => $this->t('If choosing synchro, scripts will be fetched and executed in the order defined for the group. Then all behaviors will be triggered. If choosing asynchro, scripts will be fetched in parallel and no behaviors will be triggered.'),
      ];
      $form['jsGroup' . $i]['aggregate' . $i] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Aggregate all internal files in this group into one?'),
        '#default_value' => $jsGroups[$i]['aggregate'] ?? NULL,
        '#description' => $this->t('Check this box if files need to be loaded together in order to have their behavor work properly. Within a group, aggregated files will be loaded after external ones.'),
      ];

      $form['jsGroup' . $i]['javascript' . $i] = [
        '#type' => 'textarea',
        '#title' => $this->t('Select javascript to delay, 1 javascript path per line'),
        '#default_value' => $jsGroups[$i]['javascript'] ?? NULL,
        '#description' => $this->t('1 javascript path per line. eg: @example', ['@example' => 'core/assets/vendor/html5shiv/html5shiv.min.js']),
      ];
    }

    // Provide an "Add another group" button.
    $form['add_group'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add another group'),
      '#submit' => [[$this, 'addGroup']],
    ];

    // Provide a "Remove" button for latest selected group.
    if ($nbGroups > 1) {
      $form['remove_group']['remove_group'] = [
        '#type' => 'submit',
        '#value' => $this->t('Remove last group'),
        '#submit' => [[$this, 'removeGroup']],
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * Adding a new group.
   */
  public function addGroup(array &$form, FormStateInterface $form_state) {
    $nbGroups = $form_state->getValue('nbGroups');

    $config = $this->config('libraries_delay_load.settings');
    $config->set('nbGroups', $nbGroups + 1);
    $config->save();
  }

  /**
   * Removing the last group.
   */
  public function removeGroup(array &$form, FormStateInterface $form_state) {
    $nbGroups = $form_state->getValue('nbGroups');

    $config = $this->config('libraries_delay_load.settings');
    $config->set('nbGroups', $nbGroups - 1);
    $config->save();
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('libraries_delay_load.settings');
    $config->set('enabled', $form_state->getValue('enabled'));
    $config->set('debug', $form_state->getValue('debug'));
    $config->set('jsExcluded', $form_state->getValue('jsExcluded'));

    $jsGroups = [];
    for ($i = 0; $i < $form_state->getValue('nbGroups'); $i++) {
      $setting = [];
      $setting['timing'] = $form_state->getValue('timing' . $i);
      $setting['synchro'] = $form_state->getValue('synchro' . $i);
      $setting['aggregate'] = $form_state->getValue('aggregate' . $i);
      $setting['javascript'] = $form_state->getValue('javascript' . $i);
      $jsGroups[$i] = $setting;
    }
    $config->set('jsGroups', $jsGroups);

    $config->save();

    // Clear Caches.
    Cache::invalidateTags(['library_info']);

    parent::submitForm($form, $form_state);
  }

}

==> libraries_delay_load-2.1.x-dev.tar.gz: libraries_delay_load/src/Form/ModuleConfigurationForm.php <==
<?php

namespace Drupal\libraries_delay_load\Form;

use Drupal\Core\Cache\Cache;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures forms module settings.
 */
class ModuleConfigurationForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'libraries_delay_load_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'libraries_delay_load.admin_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('libraries_delay_load.admin_settings');

    $form['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Load Delay Library?'),
      '#default_value' => $config->get('enabled') ?? 0,
      '#description' => $this->t('Disable for testing purposes.'),
    ];

    $form['debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable debug mode?'),
      '#default_value' => $config->get('debug') ?? 0,
      '#description' => $this->t('Display notices messages the first time a page is loaded to list all the javascripts loaded directly by Drupal. Also output the order of what is loaded in the console'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('libraries_delay_load.admin_settings');
    $config->set('enabled', $form_state->getValue('enabled'));
    $config->set('debug', $form_state->getValue('debug'));

    $config->save();

    // Clear Caches.
    Cache::invalidateTags(['library_info']);

    parent::submitForm($form, $form_state);
  }

}
